t_edgeworth: Edgeworth expansion for Welch's t-statistic
Description
This function provides approximation for the cumulative distribution function
of the sampling distribution of the Welch's t-statistic using Normal distribution, first order or second order Edgeworth expansion.
the order of edgeworth expansion. Valid options are 0, 1, and 2. If set to 0,
it reduces to approximation based on the central limit theorem and returns the CDF of standard normal distribution
evaluated at x.
n1
sample size for the sample from the first population.
n2
sample size for the sample from the second population.