This test is suitable for testing the equality of
two-sample means for the populations having unequal variances.
When the populations are not normally distributed, this test
can provide better type I error control and more accurate power than a large-sample t-test using normal
approximation. The critical values of the test are computed based on the
Cornish-Fisher expansion of the Welch's t-statistic. The order of the
Cornish-Fisher expansion is allowed to be 0, 1, or 2. More details
please refer to Zhang and Wang (2020).
Usage
tcfu(x1, x2, effectSize = 0, alternative = "greater", alpha = 0.05, order = 2)
Arguments
x1
the first sample.
x2
the second sample.
effectSize
the effect size of the test. The default value is 0.
alternative
the alternative hypothesis: "greater" for upper-tailed, "less" for lower-tailed, and "two.sided" for two-sided alternative.
alpha
the significance level. The default value is 0.05.
order
the order of the Cornish-Fisher expansion.
Value
test statistic, critical value, p-value, reject decision at the given significance level.
References
Zhang, H. and Wang, H. (2020). Transformation tests and their asymptotic power in two-sample comparisons. Manuscript in review.